@@ -219,8 +219,8 @@
 #endif /* HAVE_LIBC */
 
 /* #undef HAVE_ALTIVEC_H */
-/* #undef HAVE_DBUS_DBUS_H */
-/* #undef HAVE_FCITX */
+#define HAVE_DBUS_DBUS_H 1
+#define HAVE_FCITX 1
 /* #undef HAVE_IBUS_IBUS_H */
 #define HAVE_SYS_INOTIFY_H 1
 #define HAVE_INOTIFY_INIT 1
@@ -241,9 +241,9 @@
 #define HAVE_IMMINTRIN_H 1
 #endif
 
-/* #undef HAVE_LIBUDEV_H */
+#define HAVE_LIBUDEV_H 1
 /* #undef HAVE_LIBSAMPLERATE_H */
-/* #undef HAVE_LIBDECOR_H */
+#define HAVE_LIBDECOR_H 1
 
 /* #undef HAVE_D3D_H */
 /* #undef HAVE_D3D11_H */
@@ -362,7 +362,7 @@
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
 /* #undef SDL_LIBUSB_DYNAMIC */
-/* #undef SDL_UDEV_DYNAMIC */
+#define SDL_UDEV_DYNAMIC "libudev.so.1"
 
 /* Enable various sensor drivers */
 /* #undef SDL_SENSOR_ANDROID */
@@ -414,7 +414,7 @@
 #define SDL_VIDEO_DRIVER_OFFSCREEN 1
 /* #undef SDL_VIDEO_DRIVER_WINDOWS */
 /* #undef SDL_VIDEO_DRIVER_WINRT */
-/* #undef SDL_VIDEO_DRIVER_WAYLAND */
+#define SDL_VIDEO_DRIVER_WAYLAND 1
 /* #undef SDL_VIDEO_DRIVER_RPI */
 /* #undef SDL_VIDEO_DRIVER_VIVANTE */
 /* #undef SDL_VIDEO_DRIVER_VIVANTE_VDK */
@@ -428,7 +428,7 @@
 /* #undef SDL_VIDEO_DRIVER_KMSDRM_DYNAMIC */
 /* #undef SDL_VIDEO_DRIVER_KMSDRM_DYNAMIC_GBM */
 
-/* #undef SDL_VIDEO_DRIVER_WAYLAND_QT_TOUCH */
+#define SDL_VIDEO_DRIVER_WAYLAND_QT_TOUCH 1
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC */
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC_EGL */
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC_CURSOR */
@@ -459,9 +459,9 @@
 /* #undef SDL_VIDEO_RENDER_D3D */
 /* #undef SDL_VIDEO_RENDER_D3D11 */
 /* #undef SDL_VIDEO_RENDER_D3D12 */
-/* #undef SDL_VIDEO_RENDER_OGL */
-/* #undef SDL_VIDEO_RENDER_OGL_ES */
-/* #undef SDL_VIDEO_RENDER_OGL_ES2 */
+#define SDL_VIDEO_RENDER_OGL 1
+#define SDL_VIDEO_RENDER_OGL_ES 1
+#define SDL_VIDEO_RENDER_OGL_ES2 1
 /* #undef SDL_VIDEO_RENDER_DIRECTFB */
 /* #undef SDL_VIDEO_RENDER_METAL */
 /* #undef SDL_VIDEO_RENDER_VITA_GXM */
@@ -469,19 +469,19 @@
 /* #undef SDL_VIDEO_RENDER_PSP */
 
 /* Enable OpenGL support */
-/* #undef SDL_VIDEO_OPENGL */
-/* #undef SDL_VIDEO_OPENGL_ES */
-/* #undef SDL_VIDEO_OPENGL_ES2 */
+#define SDL_VIDEO_OPENGL 1
+#define SDL_VIDEO_OPENGL_ES 1
+#define SDL_VIDEO_OPENGL_ES2 1
 /* #undef SDL_VIDEO_OPENGL_BGL */
 /* #undef SDL_VIDEO_OPENGL_CGL */
-/* #undef SDL_VIDEO_OPENGL_GLX */
+#define SDL_VIDEO_OPENGL_GLX 1
 /* #undef SDL_VIDEO_OPENGL_WGL */
-/* #undef SDL_VIDEO_OPENGL_EGL */
+#define SDL_VIDEO_OPENGL_EGL 1
 /* #undef SDL_VIDEO_OPENGL_OSMESA */
 /* #undef SDL_VIDEO_OPENGL_OSMESA_DYNAMIC */
 
 /* Enable Vulkan support */
-/* #undef SDL_VIDEO_VULKAN */
+#define SDL_VIDEO_VULKAN 1
 
 /* Enable Metal support */
 /* #undef SDL_VIDEO_METAL */
@@ -533,7 +533,7 @@
 /* #undef SDL_LIBSAMPLERATE_DYNAMIC */
 
 /* Enable ime support */
-/* #undef SDL_USE_IME */
+#define SDL_USE_IME 1
 
 /* Platform specific definitions */
 /* #undef SDL_IPHONE_KEYBOARD */
@@ -543,7 +543,7 @@
 /* #undef SDL_VIDEO_VITA_PVR */
 /* #undef SDL_VIDEO_VITA_PVR_OGL */
 
-/* #undef SDL_HAVE_LIBDECOR_GET_MIN_MAX */
+#define SDL_HAVE_LIBDECOR_GET_MIN_MAX 1
 
 #if !defined(HAVE_STDINT_H) && !defined(_STDINT_H_)
 /* Most everything except Visual Studio 2008 and earlier has stdint.h now */
